import UIKit

public extension Optional where Wrapped: Collection {
    /// SwifterSwift: Check if optional is nil or empty collection.
    var isNilOrEmpty: Bool {
        guard let collection = self else { return true }
        return collection.isEmpty
    }
    
    var updatedIsNewNilOrEmpty: Bool {
        return (self == nil || self!.isEmpty)
    }
}

var randomText: String {
    return "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. "
}

let testData: [String]? = Array(repeating: randomText, count: 10_000)

/// Uses the old implementation of isNewNilOrEmpty
func timeTest1() {
    testData.isNilOrEmpty
}
/// Uses the new implementation of isNewNilOrEmpty
func timeTest2() {
    testData.updatedIsNewNilOrEmpty
}

let clock = ContinuousClock()

// This is used to compare relatively low time
let measurementOffset: Int64 = 1000

// Measure time for old and new implementations
let oldTime = clock.measure(timeTest1) * measurementOffset
let newTime = clock.measure(timeTest2) * measurementOffset

// Calculate the percentage
let diff = ((newTime - oldTime)/oldTime)*100

print("New time is \(diff < 0 ? "faster" : "slower") than old time by \(abs(diff)) % ")


